@@ -7,6 +7,8 @@
 # Website - http://www.pilas-engine.com.ar
 
 import pilas
+from PySFML import sf
+
 
 class Camara(object):
     """Representa el punto de vista de la ventana.
@@ -15,23 +17,27 @@ class Camara(object):
     punto central de la pantalla. Por defecto estos
     valores con (0, 0)."""
 
-    def __init__(self, motor):
-        self.motor = motor
+    def __init__(self, app):
+        self.view = app.GetDefaultView()
 
-    @pilas.utils.interpolable
     def _set_x(self, x):
-        pilas.mundo.motor.definir_centro_de_la_camara(x, self.y)
+        if pilas.utils.es_interpolacion(x):
+            x.apply(self, function='_set_x')
+        else:
+            self.view.SetCenter(x, self.y)
 
     def _get_x(self):
-        x, y = pilas.mundo.motor.obtener_centro_de_la_camara()
+        x, y = self.view.GetCenter()
         return x
 
-    @pilas.utils.interpolable
     def _set_y(self, y):
-        pilas.mundo.motor.definir_centro_de_la_camara(self.x, y)
+        if pilas.utils.es_interpolacion(y):
+            y.apply(self, function='_set_y')
+        else:
+            self.view.SetCenter(self.x, -y)
 
     def _get_y(self):
-        x, y = pilas.mundo.motor.obtener_centro_de_la_camara()
+        x, y = self.view.GetCenter()
         return y
 
     x = property(_get_x, _set_x)
